using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using Microsoft.Win32;

namespace GMailNotifier
{
	public partial class Settings : Form
	{
		private readonly static string m_appKey = @"Software\zenwheel\MailNotifier";
		private readonly static string m_gmailDomain = "gmail";

		public Settings()
		{
			InitializeComponent();
		}

		private static void SetRegistryValue(string key, string val)
		{
			using (RegistryKey rk = Registry.CurrentUser.CreateSubKey(m_appKey))
			{
				if (rk != null)
					rk.SetValue(key, val, RegistryValueKind.String);
			}
		}

		private static string GetRegistryValue(string key)
		{
			string result = String.Empty;
			using (RegistryKey rk = Registry.CurrentUser.OpenSubKey(m_appKey))
			{
				if (rk != null)
					result = rk.GetValue(key, String.Empty).ToString();
			}
			return (result);
		}

		public static string User
		{
			get { return(GetRegistryValue("User"));}
			set { SetRegistryValue("User", value);}
		}

		public static string Email
		{
			get
			{
				string result = User;
				if (IsGmail && result.IndexOf('@') == -1)
					result += "@gmail.com";
				return (result);
			}
		}

		public static string Password
		{
			get { return (GetRegistryValue("Password")); }
			set { SetRegistryValue("Password", value); }
		}

		public static string Domain
		{
			get { return (GetRegistryValue("Domain")); }
			set { SetRegistryValue("Domain", value); }
		}

		public static string Interval
		{
			get { return (GetRegistryValue("Interval")); }
			set { SetRegistryValue("Interval", value); }
		}

		public static int IntervalSeconds
		{
			get
			{
				int result = 1800;
				switch (Interval)
				{
					case "5m":
						result = 300;
						break;
					case "10m":
						result = 600;
						break;
					case "15m":
						result = 900;
						break;
					case "30m":
					default:
						result = 1800;
						break;
					case "1h":
						result = 3600;
						break;
					case "2h":
						result = 7200;
						break;
				}
				return (result);
			}
		}

		public static bool IsGmail
		{
			get { return (Domain == m_gmailDomain); }
		}

		private void menuItem2_Click(object sender, EventArgs e)
		{
			this.DialogResult = DialogResult.Cancel;
		}

		private void menuItem1_Click(object sender, EventArgs e)
		{
			if (textBox1.Text.IndexOf('@') == -1 && comboBox1.SelectedIndex != 0)
				textBox1.Text += String.Format("@{0}", textBox3.Text);
			User = textBox1.Text;
			Password = textBox2.Text;
			if (comboBox1.SelectedIndex == 0)
				Domain = m_gmailDomain;
			else
				Domain = textBox3.Text;

			Interval = comboBox2.Items[comboBox2.SelectedIndex].ToString();

			this.DialogResult = DialogResult.OK;
		}

		private void comboBox1_SelectedIndexChanged(object sender, EventArgs e)
		{
			if (comboBox1.SelectedIndex == 0)
				textBox3.Enabled = false;
			else
				textBox3.Enabled = true;
		}

		private void Settings_Load(object sender, EventArgs e)
		{
			textBox1.Text = User;
			textBox2.Text = Password;
			if (IsGmail)
			{
				comboBox1.SelectedIndex = 0;
				textBox3.Text = String.Empty;
				textBox3.Enabled = false;
			}
			else
			{
				comboBox1.SelectedIndex = 1;
				textBox3.Text = Domain;
				textBox3.Enabled = true;
			}
			string x = Interval;
			comboBox2.SelectedIndex = 3;
			for (int i = 0; i < comboBox2.Items.Count; i++)
			{
				if (comboBox2.Items[i].ToString() == x)
				{
					comboBox2.SelectedIndex = i;
					break;
				}
			}
		}

		private void textBox1_TextChanged(object sender, EventArgs e)
		{
			int idx = textBox1.Text.IndexOf('@');
			if (idx != -1)
			{
				// set domain, if we have one in here
				comboBox1.SelectedIndex = 1;
				textBox3.Text = textBox1.Text.Substring(idx + 1);
				textBox3.Enabled = true;
			}
		}
	}
}